﻿// © 2012 Steve Wall All rights reserved 
// This resource is licensed “as-is.” Steve Wall gives no express warranties, guarantees or conditions.

#region Using Statements
using System;
using System.ComponentModel;
using System.Linq;
using System.Windows;
using System.Windows.Input;

using Infragistics.Windows.Chart;
#endregion

namespace xamChart
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private int m_DoubleClicks = 0;

        public MainWindow()
        {
            try
            {
                InitializeComponent();

                // Bind the chart
                DataChart.Series[0].DataSource = LoadData();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "xamChart", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }

        private void DataChartOnMouseDoubleClick(object sender, MouseButtonEventArgs e)
        {
            // Attempt to drill into next dimension
            try
            {
                HitTestArgs hitTest = DataChart.HitTest(e);
                if (hitTest != null)
                {
                    DataPoint dp = hitTest.SelectedObject as DataPoint;
                    if (dp != null)
                    {
                        // Update double-click executions text box
                        ++m_DoubleClicks;
                        DoubleClickExecutionsLabel.Content = string.Format("Double-Click Executions: {0}", m_DoubleClicks);
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "xamChart", MessageBoxButton.OK, MessageBoxImage.Error);
            }
            finally
            {
                e.Handled = true;
            }
        }

        private BindingList<TopMovie> LoadData()
        {
            BindingList<TopMovie> list = new BindingList<TopMovie>();
            list.Add(new TopMovie("Open Season", "1 hr. 40 min.", DateTime.Parse("September 29, 2006"), "PG", "C", 23624548M));
            list.Add(new TopMovie("The Guardian", "2 hrs. 19 min.", DateTime.Parse("September 29, 2006"), "PG-13", "C", 18006064M));
            list.Add(new TopMovie("School For Scoundrels", "1 hr. 41 min.", DateTime.Parse("September 29, 2006"), "PG-13", "C-", 8602333M));
            list.Add(new TopMovie("Jet Li's Fearless", "1 hr. 43 min.", DateTime.Parse("September 22, 2006"), "PG-13", "B-", 18066869M));
            list.Add(new TopMovie("Gridiron Gang", "120 min.", DateTime.Parse("September 15, 2006"), "PG-13", "C+", 33258307M));
            list.Add(new TopMovie("The Illusionist", "1 hr. 49 min.", DateTime.Parse("August 18, 2006 "), "PG-13", "B", 31378443M));
            list.Add(new TopMovie("Flyboys", "2 hrs. 9 min.", DateTime.Parse("September 22, 2006"), "PG-13", "C", 9946969M));
            list.Add(new TopMovie("The Black Dahlia", "2 hrs. 1 min.", DateTime.Parse("September 15, 2006 "), "R", "C", 20742610M));
            list.Add(new TopMovie("Little Miss Sunshine", "1 hr. 41 min.", DateTime.Parse("July 26, 2006 "), "R", "B+", 53133641M));
            list.Add(new TopMovie("Facing the Giants", "1 hr. 51 min.", DateTime.Parse("September 29, 2006"), "PG", "", 1343537M));
            list.Add(new TopMovie("The Covenant", "1 hr. 37 min.", DateTime.Parse("September 8, 2006"), "PG-13", "", 22265370M));
            list.Add(new TopMovie("The Last Kiss", "1 hr. 43 min.", DateTime.Parse("September 15, 2006"), "R", "C+", 10420006M));
            list.Add(new TopMovie("Everyone's Hero", "1 hr. 26 min.", DateTime.Parse("September 15, 2006"), "G", "C+", 13307759M));
            list.Add(new TopMovie("The Science of Sleep", "1 hr. 46 min.", DateTime.Parse("September 22, 2006"), "R", "B-", 1616252M));
            list.Add(new TopMovie("Invincible", "1 hr. 48 min.", DateTime.Parse("August 25, 2006"), "PG", "B-", 56322748M));
            list.Add(new TopMovie("Hollywoodland", "126 min", DateTime.Parse("September 8, 2006"), "R", "B-", 13939745M));
            list.Add(new TopMovie("Talladega Nights: The Ballad of Ricky Bobby", "1 hr. 50 min.", DateTime.Parse("August 4, 2006"), "PG-13", "B", 14742124M));
            list.Add(new TopMovie("Pirates of the Caribbean: Dead Man's Chest", "145 min.", DateTime.Parse("July 7, 2006"), "PG-13", "B-", 42033112M));
            
            return list;
        }
    }
}
